@@ -1,6 +1,6 @@
 package EBook::MOBI::Converter;
 
-our $VERSION = '0.62'; # TRIAL VERSION (hook for Dist::Zilla::Plugin::OurPkgVersion)
+our $VERSION = '0.64'; # TRIAL VERSION (hook for Dist::Zilla::Plugin::OurPkgVersion)
 
 use strict;
 use warnings;
@@ -464,7 +464,7 @@ This program is free software; you can redistribute it and/or modify it under th
 
 =head1 AUTHOR
 
-Boris Däppen E<lt>boris_daeppen@bluewin.chE<gt>
+Boris Däppen E<lt>bdaeppen.perl@gmail.comE<gt>
 
 =cut
 
